============
utilities.py
============

Management utilities for Yet Another Photon Classifier (YAPC)

`Source code`__

.. __: https://github.com/tsutterley/yapc/blob/main/yapc/utilities.py


General Methods
===============

.. autofunction:: yapc.utilities.build_logger

.. autofunction:: yapc.utilities.convert_arg_line_to_args

.. autofunction:: yapc.utilities.copy
